@@ -163,9 +163,9 @@ _gnorba_get_cookie_reliably (const char *setme)
 			unsigned int i;
 			
 			get_exclusive_lock (fd);
-			srandom (time (NULL));
+			srand (time (NULL));
 			for (i = 0; i < sizeof (buf)-1; i++)
-				buf [i] = (random () % (126-33)) + 33;
+				buf [i] = (rand () % (126-33)) + 33;
 			
 			if(write(fd, buf, sizeof(buf)-1) < (sizeof(buf)-1)) {
                                 fprintf(stderr, _("Failed to write CORBA cookie to `%s': %s\n"), name, strerror(errno));
